==============
Covasim papers 
==============

Here is an incomplete list of papers relating to the Covasim model. You can also check `citations on Google Scholar <https://scholar.google.com/scholar?cites=293396678055528103&as_sdt=2005&sciodt=0,5&hl=en>`_. If you've written a paper or report using Covasim that isn't listed here, please write to us `here <mailto:info@covasim.org>`_.

These papers are also listed in BibTeX format in ``papers.bib``.


Covasim methods papers
======================

1. **Covasim: an agent-based model of COVID-19 dynamics and interventions**. Kerr CC, Stuart RM, Mistry D, Abeysuriya RG, Rosenfeld R, Hart G, Núñez RC, Cohen JA, Selvaraj P, Hagedorn B, George L, Jastrzębski M, Izzo A, Fowler G, Palmer A, Delport D, Scott N, Kelly S, Bennette C, Wagner B, Chang S, Oron AP, Wenger E, Panovska-Griffiths J, Famulare M, Klein DJ (2021). *PLOS Computational Biology* **17** (7): e1009149. doi: https://doi.org/10.1371/journal.pcbi.1009149.

2. **Mechanistic modeling of SARS-CoV-2 immune memory, variants, and vaccines**. Cohen JA, Stuart RM, Núñez RC, Wagner B, Chang ST, Rosenfeld K, Kerr CC, Famulare M, Klein DJ (under review; posted 2021-06-01). *medRxiv* 2021.05.31.21258018; doi: https://doi.org/10.1101/2021.05.31.21258018.


Scientific papers from the Covasim development team
===================================================

1. **Determining the optimal strategy for reopening schools, the impact of test and trace interventions, and the risk of occurrence of a second COVID-19 epidemic wave in the UK: a modelling study**. Panovska-Griffiths J, Kerr CC, Stuart RM, Mistry D, Klein DJ, Viner R, Bonnell C (2020-08-03). *Lancet Child and Adolescent Health* S2352-4642(20) 30250-9. doi: https://doi.org/10.1016/S2352-4642(20)30250-9.

2. **Controlling COVID-19 via test-trace-quarantine**. Kerr CC, Mistry D, Stuart RM, Rosenfeld R, Hart G, Núñez RC, Selvaraj P, Cohen JA, Abeysuriya RG, George L, Hagedorn B, Jastrzębski M, Fagalde M, Duchin J, Famulare M, Klein DJ (2021). *Nature Communications* 12:2993. doi: https://doi.org/10.1038/s41467-021-23276-9.

3. **Estimating and mitigating the risk of COVID-19 epidemic rebound associated with reopening of international borders in Vietnam: a modelling study**. Pham QD, Stuart RM, Nguyen TV, Luong QC, Tran DQ, Phan LT, Dang TQ, Tran DN, Mistry D, Klein DJ, Abeysuriya RG, Oron AP, Kerr CC (2021-04-12). *Lancet Global Health* S2214-109X(21) 00103-0; doi: https://doi.org/10.1016/S2214-109X(21)00103-0.

4. **Modelling the impact of reducing control measures on the COVID-19 pandemic in a low transmission setting**. Scott N, Palmer A, Delport D, Abeysuriya RG, Stuart RM, Kerr CC, Mistry D, Klein DJ, Sacks-Davis R, Heath K, Hainsworth S, Pedrana A, Stoove M, Wilson DP, Hellard M (2020). *Medical Journal of Australia*; doi: https://doi.org/10.1101/2020.06.11.20127027.

5. **The role of masks, testing and contact tracing in preventing COVID-19 resurgences: a case study from New South Wales, Australia**. Stuart RM, Abeysuriya RG, Kerr CC, Mistry D, Klein DJ, Gray R, Hellard M, Scott N (2021). *BMJ Open*; doi: https://doi.org/10.1101/2020.09.02.20186742.

6. **Modelling the potential impact of mask use in schools and society on COVID-19 control in the UK**. Panovska-Griffiths J, Kerr CC, Waites W, Stuart RM, Mistry D, Foster D, Klein DJ, Viner R, Bonnell C (2020). *Nature Scientific Reports*; doi: https://doi.org/10.1038/s41598-021-88075-0.

7. **Schools are not islands: Balancing COVID-19 risk and educational benefits using structural and temporal countermeasures**. Cohen JA, Mistry D, Kerr CC, Klein DJ (2020). *medRxiv* 2020.09.08.20190942; doi: https://doi.org/10.1101/2020.09.08.20190942.

8. **COVID-19 reopening strategies at the county level in the face of uncertainty: Multiple Models for Outbreak Decision Support**. Shea K, Borchering RK, Probert WJM, et al. (2020). *medRxiv* 2020.11.03.20225409; doi: https://doi.org/10.1101/2020.11.03.20225409.

9. **Preventing a cluster from becoming a new wave in settings with zero community COVID-19 cases**. Abeysuriya RG, Delport D, Stuart RM, Sacks-Davis R, Kerr CC, Mistry D, Klein DJ, Hellard M, Scott N (2022). *BMC Infectious Diseases* 22(1):1-5; doi: https://doi.org/10.1186/s12879-022-07180-1.

10. **Modelling the impact of reopening schools in early 2021 in the presence of the new SARS-CoV-2 variant in the UK**. Panovska-Griffiths J, Kerr CC, Waites W, Stuart RM, Mistry D, Foster D, Klein DJ, Viner R, Bonnell C (2021). *medRxiv* 2021.02.07.21251287; doi: https://doi.org/10.1101/2021.02.07.21251287.


Scientific papers from external authors
=======================================

1. **Partial lockdown on unvaccinated individuals promises breaking of fourth COVID-19 wave in Bavaria.** Krebs T, Moeckel MJ.  *medRxiv* 2021.11.28.21266959; doi: https://doi.org/10.1101/2021.11.28.21266959.

2. **Returning to a normal life via COVID-19 vaccines in the United States: a large-scale Agent-Based simulation study**. Li J, Giabbanelli P. *JMIR Medical Informatics* 2021 Apr 29;9(4):e27419.

3. **An agent-based model to assess large-scale COVID-19 vaccination campaigns for the Italian territory: The case study of Lombardy region.** Cattaneo A, Vitali A, Mazzoleni M, Previdi F. *Computer Methods and Programs in Biomedicine* 2022 Sep 1;224:107029.

4. **Estimation of local time-varying reproduction numbers in noisy surveillance data.** Li W, Bulekova K, Gregor B, White LF, Kolaczyk ED. *Philosophical Transactions of the Royal Society A* 2022 Oct 3;380(2233):20210303.

5. **A simulation-deep reinforcement learning (SiRL) approach for epidemic control optimization.** Bushaj S, Yin X, Beqiri A, Andrews D, Büyüktahtakın İE. *Annals of Operations Research* 2022 Sep 26:1-33.